%define anolis_release 1

Name:    libuser
Version: 0.64
Release: %{anolis_release}%{?dist}
Summary: A user and group account administration library
License: LGPLv2+
URL: https://pagure.io/libuser

Source0: https://releases.pagure.org/%{name}/%{name}-%{version}.tar.gz

BuildRequires: glib2-devel
BuildRequires: linuxdoc-tools
BuildRequires: pam-devel
BuildRequires: popt-devel
BuildRequires: cyrus-sasl-devel
BuildRequires: libselinux-devel
BuildRequires: openldap-devel
BuildRequires: python3-devel
# To make sure the configure script can find it
BuildRequires: gcc
# For %%check
BuildRequires: openldap-clients
BuildRequires: openldap-servers
BuildRequires: openssl
BuildRequires: make
BuildRequires: bison
BuildRequires: libtool
BuildRequires: gettext-devel
BuildRequires: gtk-doc
BuildRequires: audit-libs-devel

%global __provides_exclude_from ^(%{_libdir}/%{name}|%{python3_sitearch})/.*$

%description
The libuser library implements a standardized interface for manipulating
and administering user and group accounts.  The library uses pluggable
back-ends to interface to its data sources.

Sample applications modeled after those included with the shadow password
suite are included.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary: Files needed for developing applications which use libuser
Requires: %{name} = %{version}-%{release}
Requires: glib2-devel

%description devel
The libuser-devel package contains header files, static libraries, and other
files useful for developing applications with libuser.

%package -n python3-libuser
Summary: Python 3 bindings for the libuser library
Requires: libuser = %{version}-%{release}
Provides: libuser-python3 = %{?epoch:%{epoch}:}%{version}-%{release}
Obsoletes: libuser-python3 < 0.63-4
%{?python_provide:%python_provide python3-libuser}

%description -n python3-libuser
The python3-libuser package contains the Python bindings for
the libuser library, which provides a Python 3 API for manipulating and
administering user and group accounts.

%prep
%autosetup -p 1

%build
./autogen.sh
%configure --with-selinux --with-ldap --with-audit \
           --enable-gtk-doc --with-html-dir=%{_datadir}/gtk-doc/html \
           PYTHON=%{python3}
make


%install
%make_install

%generate_compatibility_deps

%find_lang %{name}

%check
%make_build check || { cat test-suite.log; false; }

# Verify that all python modules load, just in case.
LD_LIBRARY_PATH=$RPM_BUILD_ROOT/%{_libdir}:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH
PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch}
export PYTHONPATH
%{python3} -c "import libuser"


%ldconfig_scriptlets

%files -f %{name}.lang
%dir %{abidir}
%license COPYING
%config(noreplace) %{_sysconfdir}/libuser.conf

%attr(0755,root,root) %{_bindir}/*
%{_libdir}/*.so.*
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/*.so
%attr(0755,root,root) %{_sbindir}/*
%{_mandir}/man1/*
%{_mandir}/man5/*
%{abidir}/*-option.list
%{abidir}/*.dump

%files doc
%doc AUTHORS NEWS README TODO docs/*.txt

%files -n python3-libuser
%doc python/modules.txt
%{python3_sitearch}/*.so

%files devel
%{_includedir}/libuser
%{_libdir}/*.so
%{_libdir}/pkgconfig/*
%{_datadir}/gtk-doc/html/*

%changelog
* Fri Feb 17 2023 Guyu Wang <guyu.wgy@linux.alibaba.com> - 0.64-1
- Update to 0.64

* Wed Oct 19 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.63-3
- optimise spec file

* Sun Oct 09 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.63-2
- add doc package

* Mon Mar 14 2022 Peng Zhou <zhoupeng@linux.alibaba.com> - 0.63-1
- Initial packaging for Anolis OS 23
